#!/bin/bash

# This script validates most of the variables in tpm_install.req file


####################
#Validate HOSTNAME
####################

. ./tpm_install.req

if [ $(cat tpm_install.req | gawk '/^HOSTNAME/'| wc -l) -ne 1 ]; then
                printf "\n\nHOSTNAME - mandatory but not defined or defined multiple times\n\n"
                exit 101
fi

echo $HOSTNAME | grep "\." 2>&1 >/dev/null
if [ $? != 0 ];then
        printf "\n\nHostname $HOSTNAME is not a fully qualified name\n\n"
        exit 101
fi

echo "$HOSTNAME" | grep '[a-zA-Z]' 2>&1 > /dev/null
if [ $? != 0 ];then
        printf "\n\nInvalid Hostname $HOSTNAME\n\n"
        exit 101
fi


##########################
# Validate DB2_ADMIN_USER
##########################

DB2ADMIN_USER=`awk 'BEGIN {FS="\""}
{
if ($1 == "DB2_ADMIN_USER=") { print $2;
                                if ((x=index($2, "\"")) > 0) {
                                DB2ADMIN_USER=substr($2,x+1,length($2)-2);
}
}
}
' tpm_install.req `


DB2_USER=`echo "$DB2ADMIN_USER"  | awk ' $1 !~ /^[a-zA-Z0-9]+$/  { print "fail" } ' | grep fail `
if [ "$DB2_USER" = "fail" ]
   then
   echo " ${DB2ADMIN_USER} : Please do not use special characters in DB2 Admin User name."
   exit 2
fi

#########################
# Validate DB2_ADMIN_PWD
#########################

DB2ADMIN_PWD=`awk 'BEGIN {FS="\""}
{
if ($1 == "DB2_ADMIN_PWD=") { print $2;
                                if ((x=index($2, "\"")) > 0) {
                                DB2ADMIN_PWD=substr($2,x+1,length($2)-2);
}
}
}
' tpm_install.req `


VALID_DB_PWD=`echo "$DB2ADMIN_PWD"  | awk ' $1 !~ /^[a-zA-Z0-9]+$/ { print "fail" } ' | grep fail `
if [ "$VALID_DB_PWD" = "fail" ]
   then
   echo " ${DBADMIN_PWD} : DB_ADMIN_PWD name is not valid. Please modify the tpm_install.req file."
   exit 2
fi


########################
# Validate ITDS_DB_HOME
########################

ITDS_DB_HOME_NAME=`awk 'BEGIN {FS="\""}
{
if ($1 == "ITDS_DB_HOME=") { print $2;
                                if ((x=index($2, "\"")) > 0) {
                                ITDS_DB_HOME_NAME=substr($2,x+1,length($2)-2);
}
}
}
' tpm_install.req `


VALID_DB_HOME=`echo "$ITDS_DB_HOME_NAME" | awk 'length($1) ~ 1 && $1 ~ /^[a-zA-Z]/'`

if [ "$VALID_DB_HOME" = "" ]
   then
   echo " $ITDS_DB_HOME_NAME : ITDS_DB_HOME name is not valid. Please modify the tpm_install.req file." 
   exit 2
fi


################################
# Validate ITDS_ADMIN_PWD
################################

ITDSADMIN_PWD=`awk 'BEGIN {FS="\""}
{
if ($1 == "ITDS_ADMIN_PWD=") { print $2;
                                if ((x=index($2, "\"")) > 0) {
                                ITDSADMIN_PWD=substr($2,x+1,length($2)-2);
}
}
}
' tpm_install.req `


ADMIN_PWD=`echo "$ITDSADMIN_PWD"  | awk ' $1 !~ /^[a-zA-Z0-9]+$/ { print "fail" } ' | grep fail `
if [ "$ADMIN_PWD" = "fail" ]
   then
   echo  " ${ITDSADMIN_PWD} : Please do not use special characters in ITDS Admin password. "
   exit 2
fi


################################
# Validate ITDS_DB_ADMIN_USER
################################

ITDSADMIN_USER=`awk 'BEGIN {FS="\""}
{
if ($1 == "ITDS_DB_ADMIN_USER=") { print $2;
                                if ((x=index($2, "\"")) > 0) {
                                ITDSADMIN_USER=substr($2,x+1,length($2)-2);
}
}
}
' tpm_install.req `


ITDS_USER=`echo "$ITDSADMIN_USER"  | awk ' $1 !~ /^[a-zA-Z0-9]+$/  { print "fail" } ' | grep fail `
if [ "$ITDS_USER" = "fail" ]
   then
   echo  " ${ITDSADMIN_USER} : Please do not use special characters. "
   exit 2
fi


################################
# Validate ITDS_DB_ADMIN_PWD
################################

ITDSDBADMIN_PWD=`awk 'BEGIN {FS="\""}
{
if ($1 == "ITDS_DB_ADMIN_PWD=") { print $2;
                                if ((x=index($2, "\"")) > 0) {
                                ITDSDBADMIN_PWD=substr($2,x+1,length($2)-2);
}
}
}
' tpm_install.req `


ADMIN_PWD=`echo "$ITDSDBADMIN_PWD"  | awk ' $1 !~ /[a-zA-Z0-9]+$/ { print "fail" } ' | grep fail `

if [ "$ADMIN_PWD" = "fail" ]
   then
   echo  "  "$ITDSDBADMIN_PWD": Please do not use special characters. "
   exit 2
fi


################################
# Validate ITDS_DB_NAME
################################

ITDSDB_NAME=`awk 'BEGIN {FS="\""}
{
if ($1 == "ITDS_DB_NAME=") { print $2;
                                if ((x=index($2, "\"")) > 0) {
                                ITDSDB_NAME=substr($2,x+1,length($2)-2);
}
}
}
' tpm_install.req `

ITDS_NAME=`echo "$ITDSDB_NAME"  | awk ' $1 !~ /^[a-zA-Z0-9]+$/ { print "fail" }' |grep fail `
if [ "$ITDS_NAME" = "fail" ]
   then
   echo  "  "$ITDSDB_NAME": Please do not use special characters. "
   exit 2
fi

LEN_DB_NAME=`echo $ITDSDB_NAME | awk ' {print length($0)}'`
echo "${LEN_DB_NAME}"

if [ "${LEN_DB_NAME}" -gt 8 ]
then
     echo " Length of ITDS_DB_NAME: $ITDSDB_NAME is greater then 8 characters. Please change ITDS_DB_NAME."
     exit 2
fi


################################
# Validate TIO_ADMIN_PWD
################################

TIOADMIN_PWD=`awk 'BEGIN {FS="\""}
{
if ($1 == "TIO_ADMIN_PWD=") { print $2;
                                if ((x=index($2, "\"")) > 0) {
                                TIOADMIN_PWD=substr($2,x+1,length($2)-2);
}
}
}
' tpm_install.req `


TIO_PWD=`echo "$TIOADMIN_PWD"  | awk ' $1 !~ /^[a-zA-Z0-9]+$/ { print "fail" } ' | grep fail `

if [ "$TIO_PWD" = "fail" ]
   then
   echo  "  "$TIOADMIN_PWD": Please do not use special characters. "
   exit 2
fi


################################
# Validate TIO_DB_NAME
################################

TIO_DB=`awk 'BEGIN {FS="\""}
{
if ($1 == "TIO_DB_NAME=") { print $2;
                                if ((x=index($2, "\"")) > 0) {
                                TIO_DB=substr($2,x+1,length($2)-2);
}
}
}
' tpm_install.req `


TIO_DBNAME=`echo "$TIO_DB"  | awk ' $1 !~ /^[a-zA-Z0-9]+$/  { print "fail" } ' | grep fail `


if [ "$TIO_DBNAME" = "fail" ]
   then
   echo  "  "$TIO_DB": Please do not use special characters. "
   exit 2
fi

exit
