#!/bin/bash 

# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

TIOADMIN=tioadmin
RUNNER=root
NUMPARMS=2

if [ $# -lt  $NUMPARMS ]; then
   echo "Usage: `basename $0` <install_image_dir> <ismp_response_file> [WAS user] [WAS pwd]"
   exit $LINENO
fi

case `uname` in
   CYGW*)
	RUNNER=$admin_user
	# RUNNER=tioadmin
	;;
   *)
	RUNNER=root
	;;
esac
ME=`id | awk '{ print $1 }' | sed -e 's/.*(\(.*\)).*/\1/'`
echo "runner: $RUNNER, me:$ME"
if [ "$RUNNER" != "$ME" ]; then
  echo "%install_tpm-E-RUNAS, This script must be executed by user $RUNNER"
  exit $LINENO
fi


TARGET_DIR=`echo "$1" | sed -e 's/\\\/\//g'`
INST_RESPONSE=`echo "$2" | sed -e 's/\\\/\//g'`
WAS_USER=$3
WAS_PWD=$4
REINIT_LOG=/tmp/tclog/init_out.log

WASUPCODE=ADMU3000I
WASDOWNCODE=ADMU4000I


SETUP_HOME=`dirname "$0"`
[ "$SETUP_HOME" = "." ] && SETUP_HOME=`pwd`

# Get environment variables from response file 
#
TIO_HOME=`cat "$INST_RESPONSE"|grep -v '^#' |grep "WzdIP_TCHome.TCHome="| cut -d '"' -f 2 |sed -e's/\\\/\//g'`
[ -z "$TIO_HOME" ] && echo "%install_tpm-E-TIOHOME, Unable to setup variable TIO_HOME" && exit $LINENO

WAS_HOME=`cat "$INST_RESPONSE"|grep -v '^#' |grep "WzdIP_WAS.InstallDir"| cut -d '"' -f 2 |sed -e's/\\\/\//g'`
[ -z "$WAS_HOME" ] && echo "%install_tpm-E-TIOHOME, Unable to setup variable TIO_HOME" && exit $LINENO

echo "TIO_HOME:$TIO_HOME; WAS_HOME:$WAS_HOME;"

PLATFORM=UNIX
case `uname` in
    CYGWIN*)
	PLATFORM=CYGWIN
	TARGETFILE=`cygpath -u "$TARGET_DIR/setupwin32.exe"`
	TARGETFILE_WIN=`cygpath -sw "$TARGET_DIR/setupwin32.exe"`
	INST_RESPONSE_CYG=`cygpath -u "$INST_RESPONSE"`
	INST_RESPONSE_WIN=`cygpath -sw "$INST_RESPONSE"`
	if [ ! -r "$INST_RESPONSE_CYG" ]; then
  		echo "%install_tpm-E-BADFILE, File not found or not readable: $INST_RESPONSE_CYG"
		exit $LINENO
	fi

        WSSTART=`cygpath -sw "$WAS_HOME/bin/startserver.bat"`
        WSSTOP=`cygpath -sw "$WAS_HOME/bin/stopserver.bat"`

        # Get CYG_ROOT from response file
       # CYG_ROOT=`cat "$INST_RESPONSE"|grep -v '^#' |grep "cygwinbean.cygwin_dir="|cut -d '"' -f 2`
       # if [ -z "$CYG_ROOT" ]; then
       #    echo "%install_tpm-E-CYG_ROOT, Unable to setup variable CYG_ROOT" 
       #    exit $LINENO
       # fi
       # echo "CYG_ROOT:$CYG_ROOT"
        INSTCMD="${TARGETFILE_WIN} -options ${INST_RESPONSE_WIN} -silent" 
        echo "UNINSTCMD:$UNINSTCMD"
	echo "INSTCMD:$INSTCMD"
        LOG_DIR_WIN="/cygdrive/c/winnt/temp"
	WIN_WAIT=1500
	;;
    *)
	if [ ! -r "$INST_RESPONSE" ]; then
  		echo "%install_tpm-E-BADFILE, File not found or not readable: $INST_RESPONSE"
		exit $LINENO
	fi
      ;;
esac


# Validate files
#
if [ ! -r "$TARGETFILE" ]; then
   echo "%install_tpm-E-BADFILE, File not found or not readable: $TARGETFILE"
   exit $LINENO
fi

# Stop TIO first 
#
echo "%install_tpm-I-TIOSTOP: stop TIO blindly"

case $PLATFORM in
    UNIX)
         [ -x "$TIO_HOME"/tools/tio.sh ] && su - $TIOADMIN -c ". "$TIO_HOME"/.TCprofile; "$TIO_HOME"/tools/tio.sh stop $WAS_USER $WAS_PWD"

         # Clear up log dir for installer
         #
         [ -d /tmp/tclog_old ] && ( cd /tmp ; rm -r tclog_old)
         [ -d /tmp/tclog ] && ( cd /tmp ; mv tclog tclog_old)
	 ;;
    CYGWIN)
         # STOP WAS first
	 if [ -z "$WAS_USER" ] && [ -z "$WAS_PWD" ]; then
		cmd /c "$WSSTOP server1" |grep "$WASDOWNCODE"
	 else
         	cmd /c "$WSSTOP server1 -user $WAS_USER -password $WAS_PWD" | grep "$WASDOWNCODE"
	 fi
  	 # This is to kill left-over processes (including DE and PE)
         ps -W | egrep 'java|eclipse' | awk '{ print $1 }' |\
         while read PID
         do
           /bin/kill -f $PID
         done

         # Clear up log dir for installer
         #
         [ -d $LOG_DIR_WIN/tclog_old ] && ( cd $LOG_DIR_WIN; rm -r  tclog_old )
         [ -d $LOG_DIR_WIN/tclog ] && ( cd $LOG_DIR_WIN; mv tclog tclog_old )
	;;
esac



# Start WAS before install TIO 
#
echo "%install_tpm-I-STARTWAS, Start up WAS before silent installation"
case $PLATFORM in
    UNIX) 
        # stop WAS blindly  
	if [ -z "$WAS_USER" ] && [ -z "$WAS_PWD" ]; then
        	$WAS_HOME/bin/stopServer.sh server1
		$WAS_HOME/bin/startServer.sh server1 | grep "$WASUPCODE"
	else
        	$WAS_HOME/bin/stopServer.sh server1 -user $WAS_USER -password $WAS_PWD
		$WAS_HOME/bin/startServer.sh server1 -user $WAS_USER -password $WAS_PWD| grep "$WASUPCODE"
	fi
        if [ $? -ne 0 ]; then
             echo "%install_tpm-E-CANTSTARTWAS, Unable to start WAS server1"
             exit $LINENO
        fi
 	;;
    CYGWIN)
	# stop WAS blindly 
	if [ -z "$WAS_USER" ] && [ -z "$WAS_PWD" ]; then
		cmd /c "$WSSTOP server1" |grep "$WASDOWNCODE"
		# then start it
                cmd /c "$WSSTART server1" | grep "$WASUPCODE"
	else
        	cmd /c "$WSSTOP server1 -user $WAS_USER -password $WAS_PWD" | grep "$WASDOWNCODE"
        	# then start it 
		cmd /c "$WSSTART server1 -user $WAS_USER -password $WAS_PWD" | grep "$WASUPCODE"
	fi
        if [ $? -ne 0 ]; then
             echo "%install_tpm-E-CANTSTARTWAS, Unable to start WAS server1"
             exit $LINENO
        fi
	
        ;;
esac

# Install TIO package
#
#echo "Target file :$TARGETFILE"
echo "%install_tpm-I-INST: running silent installation"
echo "$TARGETFILE -options $INST_RESPONSE -silent"
case $PLATFORM in
    UNIX)
         echo "$TARGETFILE -options $INST_RESPONSE -silent"
         "$TARGETFILE" -options "$INST_RESPONSE" -silent
         ;;
    CYGWIN)
         cmd /c "$INSTCMD"
         ;;
esac

if [ $? -ne 0 ]; then
   echo "%install_tpm-E-CANTINST, Unable to install TIO package"
   exit $LINENO
fi

# Cat some important logs from installer
case $PLATFORM in
    CYGWIN)
       sleep $WIN_WAIT

       # check if uninstaller dir was generated
       if [  ! -d "$TIO_HOME"/_uninst/_uninstTIO ] && [ ! -d "$TIO_HOME"/_uninst/_uninstTPM ]; then
         
          echo "%install_tpm-I-FAIL, install failed."
          exit $LINENO
       fi
       
       ;;
    UNIX)
       ;;
esac

echo "%install_tpm-I-SUCCESS, TIO has been successfully installed from CD image"
exit 0
