#!/bin/bash
#

# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

#
# Check which version of Cygwin is installed. 
#

CYG_VERSION=`uname -r|awk -F '(' '{print $1}'| awk -F '.' '{print $3}'`

  if [ "$CYG_VERSION" -lt "9" ]
  then
       echo "**** Cygwin version: `uname -r` is installed. This version is not supported. Please install Cygwin version 1.5.9 or greater."

  exit 2
  else
       echo "**** Cygwin version: `uname -r` is installed."
  fi


#
# Check if Cygwin is installed with Text File Type - UNIX
# If not change to UNIX

CHK_TYPE="`mount -m|grep "/cygdrive"|awk -F '-' '{print $3}'|uniq`"

case "$CHK_TYPE" in

"b " )
    echo "**** Cygwin is installed with Default Text File Type - UNIX"
;;

"t " )
    echo "**** Cygwin is installed with Text File Type - Dos. Changed to Text File Type - UNIX."
    eval "`mount -m | grep -i "[cygwin|cygdrive]" | sed 's/-t/-b/'`"
;;

*)
echo "**** Text File Type not known, could not change to Default Text File Type - UNIX"
exit 2
;;

esac

#
# Remove Control-M from files in tpm_install directory
#
if [ -f ./Remove_ctrl_M.sh ]
then
    ./Remove_ctrl_M.sh > ./Remove_ctrl_M.log 
    if [ $? -ne 0 ]
    then
        echo "**** Could not remove Control-M from files"
        exit 2
    else 
        echo "**** Removed Control-M character from files in tpm_install directory"
    fi
else
    echo "**** Could not find file Remove_ctrl_M.sh. Exiting..."
    exit 2
fi

#
# Start Windows Firewall/Internet connection sharing (ICS)
#

COMMAND=`NET START | grep ICS`

if [ "$COMMAND" == "   Windows Firewall/Internet Connection Sharing (ICS)" ]
then
     echo "**** Windows Firewall/Internet Connection Sharing (ICS) service is already started!"
else
     echo "**** Windows Firewall/Internet Connection Sharing (ICS) service is not started. Starting the service now..."

     nohup NET START SharedAccess  > ./test
     cat ./test | grep "error 1058"
     if [ $? -eq 0 ]; then
        echo " Windows Firewall/Internet Connection Sharing (ICS) is disabled. Please manually enable this Service. Update exec-flow.txt before running the installation (i.e. replace failed with not_ready)."
     rm -f ./test 
     exit 2
     fi
     rm ./test 
fi

#
# Disable Windows Firewall
#

Echo "**** Disabled Windows Firewall."
netsh firewall set opmode mode=DISABLE profile=STANDARD 2>&1 > tmpfile

#
# Stop Windows Management Instrumentation Service
#

echo "**** Stopped Windows Management Instrumentation Service."
 nohup net stop winmgmt > ./tmp

#
# Change Terminal mode to install
#
change user /install 

#
# Validate Response file, tpm_install.req
#

if [ -f ./Validate_Responsefile.sh ]
then
    ./Validate_Responsefile.sh 
     if [ $? -ne 0 ]
     then
          echo "Variables are not correctly decleared in tpm_install.req file. Please check the file. Exiting."
          exit 2
     fi

else
    echo "**** Could not find ./Validate_Responsefile.sh. Exiting...."
    exit 2
fi 


#
# Clean up
#
rm ./Remove_ctrl_M.log
rm ./Filelist_to_Remove_ctrl_M
rm ./tmpfile
rm ./tmp

exit
