@echo off
rem
rem Licensed Materials - Property of IBM
rem 5724-F75
rem (C) Copyright IBM Corp.  2004
rem All Rights Reserved
rem US Government Users Restricted Rights -Use, duplication or
rem disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
rem Configure IBMDS before it can be used.
rem 1. Set administrator password
rem 2. Configure LDAP database
rem	-any existing DB instance and DB will be destroyed
rem 3. Start LDAP server
rem
@echo off


set ERR_IBMDS_CONFIGDB_SERVER_STARTED=111
set ERR_IBMDS_CONFIGDB_ADMIN_PWD=112
set ERR_IBMDS_CONFIGDB_CREATE_DB=113
set ERR_IBMDS_CONFIGDB_START_SERVER=114

set RC_LDAP_SERVER_STARTED=247

set SERVER_HOME=%1
set ADMIN_DN=%2
set ADMIN_PWD=%3
set DB_ADMIN_USR=%4
set DB_ADMIN_PWD=%5
set DB_DIR=%6
set DB_NAME=%7
set CYG_ROOT=%8

set TMP_OUT=%TEMP%\ibmds_configdb%RANDOM%.tmp

echo Start local LDAP configuration
echo.

:: Step 1: Set administrator password
echo Configure LDAP administrator password...
"%SERVER_HOME%\bin\ldapcfg" -u %ADMIN_DN% -p %ADMIN_PWD% -n

set RC=%ERRORLEVEL%

IF %RC% == %RC_LDAP_SERVER_STARTED% (
	echo LDAP server must be stopped during configuration. Please stop the server and run install again.
	echo Failed to configure LDAP administrator password - exit %ERR_IBMDS_CONFIGDB_SERVER_STARTED%
	exit %ERR_IBMDS_CONFIGDB_SERVER_STARTED%)

IF NOT %RC% == 0 (
	echo Failed to configure LDAP administrator password - exit %ERR_IBMDS_CONFIGDB_ADMIN_PWD%
	exit %ERR_IBMDS_CONFIGDB_ADMIN_PWD%)

:: Step 2: Create LDAP database
echo.
echo Create and configure LDAP database...
echo.

cd /d %DB_DIR%\
"%SERVER_HOME%\bin\ldapcfg.exe" -l %DB_DIR% -a %DB_ADMIN_USR% -w %DB_ADMIN_PWD% -d %DB_NAME% -i -o -c -n > %TMP_OUT%
type %TMP_OUT%

:: ldapcfg returns 0 even if DB configuration fails, grep output to check result
"%CYG_ROOT%\bin\grep" "Configured IBM Tivoli Directory Server Database." "%TMP_OUT%" > NUL

set RC=%ERRORLEVEL%

IF NOT %RC% == 0 (
	echo Failed to configure LDAP database - exit %ERR_IBMDS_CONFIGDB_CREATE_DB%
	del "%TMP_OUT%"
	exit %ERR_IBMDS_CONFIGDB_CREATE_DB%)

del "%TMP_OUT%"

: Step 3: Start LDAP server
echo.
echo Start LDAP server...
echo.

:: check if LDAP admin daemon service is up, if not, start it
tasklist | "%CYG_ROOT%\bin\grep" ibmdiradm > NUL

set RC=%ERRORLEVEL%

IF NOT %RC% == 0 (
	net start ibmdiradm)

:: start LDAP server service
net start ibmslapd

set RC=%ERRORLEVEL%

IF NOT %RC% == 0 (
	echo Failed to start LDAP server - exit %ERR_IBMDS_CONFIGDB_START_SERVER%
	exit %ERR_IBMDS_CONFIGDB_START_SERVER%)

echo.
echo Local LDAP configuration finished successfully - exit 0

exit 0
