#!/usr/bin/env bash

# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

#_________________________________________________________
#                                                         #
# Check if all the required parameters are defined        #
#_________________________________________________________#
#

while read resp_var
do
        respresp_var="\$$resp_var"
        if [ -z "`eval echo $respresp_var`" ]; then
                printf "$resp_var - mandatory but not defined\n"
                var_error=1
        fi
done < ./response_options.txt

if [ "$var_error" = "1" ]; then
        exit 101
fi

#_________________________________________________________
#                                                         #
# Check the validity of the source folders                #
#_________________________________________________________#
#

if [ ! -d "$BASE_DIR" -o -z "$BASE_DIR" ]; then
	echo "Invalid path BASE_DIR=\"$BASE_DIR\""
	exit 101
fi

if [ ! -d "$BASE_DIR\\$PICS_SRC" -o -z "$PICS_SRC" ]; then
	echo "Invalid path PICS_SRC=\"$PICS_SRC\""
	exit 101
fi

if [ ! -d "$BASE_DIR\\$DB2_SRC" -o -z "$DB2_SRC" ]; then
	echo "Invalid path DB2_SRC=\"$DB2_SRC\""
	exit 101
fi

if [ ! -d "$BASE_DIR\\$DB2_FIXPACK_SRC" -o -z "$DB2_FIXPACK_SRC" ]; then
	echo "Invalid path DB2_FIXPACK_SRC=\"$DB2_FIXPACK_SRC\""
	exit 101
fi

if [ ! -d "$BASE_DIR\\$ITDS_SRC" -o -z "$ITDS_SRC" ]; then
	echo "Invalid path ITDS_SRC=\"$ITDS_SRC\""
	exit 101
fi

if [ ! -d "$BASE_DIR\\$WAS_SRC" -o -z "$WAS_SRC" ]; then
	echo "Invalid path WAS_SRC=\"$WAS_SRC\""
	exit 101
fi

if [ ! -d "$BASE_DIR\\$FIX_DIR" -o -z "$FIX_DIR" ]; then
	echo "Invalid path FIX_DIR=\"$FIX_DIR\""
	exit 101
fi

if [ ! -d "$BASE_DIR\\$TPM_SRC" -o -z "$TPM_SRC" ]; then
	echo "Invalid path TPM_SRC=\"$TPM_SRC\""
	exit 101
fi

if [ ! -d "$BASE_DIR\\$TPM_FIXPACK1" -o -z "$TPM_FIXPACK1" ]; then
	echo "Invalid path TPM_FIXPACK1=\"$TPM_FIXPACK1\""
	exit 101
fi

#_________________________________________________________
#                                                         #
# Check the validity of the destination paths             #
#_________________________________________________________#
#

if [ -n "$(echo $DB2_HOME | grep " ")" -o -z "$DB2_HOME" -o ! -d "${DB2_HOME%:*}:" ]; then
	echo "DB2_HOME=\"$DB2_HOME\" contains spaces or is not a valid path"
	exit 101
fi 

if [ -n "$(echo $ITDS_HOME | grep " ")" -o -z "$ITDS_HOME" -o ! -d "${ITDS_HOME%:*}:" ]; then
	echo "ITDS_HOME=\"$ITDS_HOME\" contains spaces or is not a valid path"
	exit 101
fi 

if [ -n "$(echo $WAS_HOME | grep " ")" -o -z "$WAS_HOME" -o ! -d "${WAS_HOME%:*}:" ]; then
	echo "WAS_HOME=\"$WAS_HOME\" contains spaces or is not a valid path"
	exit 101
fi 

if [ -n "$(echo $TPM_HOME | grep " ")" -o -z "$TPM_HOME" -o ! -d "${TPM_HOME%:*}:" ]; then
	echo "TPM_HOME=\"$TPM_HOME\" contains spaces or is not a valid path"
	exit 101
fi 


#_________________________________________________________
#                                                         #
# Check the disk space                                    #
#_________________________________________________________#
#

tpm_size=9000
db2_size=2000
was_size=2000
itds_size=2000

TPM_HOME_CYG=$(cygpath "${TPM_HOME%%\\*}")
DB2_HOME_CYG=$(cygpath "${DB2_HOME%%\\*}")
WAS_HOME_CYG=$(cygpath "${WAS_HOME%%\\*}")
ITDS_HOME_CYG=$(cygpath "${ITDS_HOME%%\\*}")

tpm_free=$(df -m $TPM_HOME_CYG | gawk '/\/cygdrive\// {print $4}')
db2_free=$(df -m $DB2_HOME_CYG | gawk '/\/cygdrive\// {print $4}')
was_free=$(df -m $WAS_HOME_CYG | gawk '/\/cygdrive\// {print $4}')
itds_free=$(df -m $WAS_HOME_CYG | gawk '/\/cygdrive\// {print $4}')

if [ "$TPM_HOME_CYG" = "$DB2_HOME_CYG" ]; then
	let "tpm_size = $tpm_size + $db2_size"
fi

if [ "$TPM_HOME_CYG" = "$ITDS_HOME_CYG" ]; then
	let "tpm_size = $tpm_size + $itds_size"
fi

if [ "$TPM_HOME_CYG" = "$WAS_HOME_CYG" ]; then
	let "tpm_size = $tpm_size + $was_size"
fi

if [ $tpm_free -lt $tpm_size ]; then 
	printf "\n\nA minimum of $tpm_size MB of free hard disk is required on drive $TPM_HOME_CYG\n\n"
	exit 101
fi

if [ "$DB2_HOME_CYG" = "$ITDS_HOME_CYG" ]; then
	let "db2_size = $db2_size + $itds_size"
fi

if [ "$DB2_HOME_CYG" = "$WAS_HOME_CYG" ]; then
	let "db2_size = $db2_size + $was_size"
fi

if [ $db2_free -lt $db2_size ]; then 
	printf "\n\nA minimum of $db2_size MB of free hard disk is required on drive $DB2_HOME_CYG\n\n"
	exit 101
fi

if [ "$ITDS_HOME_CYG" = "$WAS_HOME_CYG" ]; then
	let "itds_size = $itds_size + $was_size"
fi

if [ $itds_free -lt $itds_size ]; then 
	printf "\n\nA minimum of $itds_size MB of free hard disk is required on drive $ITDS_HOME_CYG\n\n"
	exit 101
fi

if [ $was_free -lt $was_size ]; then 
	printf "\n\nA minimum of $was_size MB of free hard disk is required on drive $WAS_HOME_CYG\n\n"
	exit 101
fi

#_________________________________________________________
#                                                         #
# Check if the HOSTNAME is a valid name and not an IP     #
# Check if SUS_IP_ADDRESS is a valid IP                   #
#_________________________________________________________#
#

if [ $(cat tpm_install.req | gawk '/^HOSTNAME/'| wc -l) -ne 1 ]; then
		printf "\n\nHOSTNAME - mandatory but not defined or defined multiple times\n\n"
		exit 101
fi

echo $HOSTNAME | grep "\." 2>&1 >/dev/null
if [ $? != 0 ];then 
	printf "\n\nHostname $HOSTNAME is not a FQ name\n\n"
	exit 101
fi

echo "$HOSTNAME" | grep '[a-zA-Z]' 2>&1 > /dev/null
if [ $? != 0 ];then 
	printf "\n\nInvalid Hostname $HOSTNAME\n\n"
	exit 101
fi

sus_check=`printf ".${SUS_IP_ADDRESS}." | gawk --re-interval '/\.([0-9]{1,3}\.){3}[0-9]{1,3}\./ {print}' | wc -l`
if [ $sus_check != 1 ]; then
	printf "\n\n$SUS_IP_ADDRESS is not a valid IP address\n\n"
	exit 101
fi

#_________________________________________________________
#                                                         #
# Check if the HOSTNAME is alive                          #
#_________________________________________________________#
#

ping_result=$(/usr/bin/ping $HOSTNAME 64 3)

if [ -n "$(echo $ping_result | grep "100.0% packet loss")" -o \
     -n "$(echo $ping_result | grep "ping: unknown host")" ]; then
	printf "\n\n$HOSTNAME is unreachable, please verify if the name is registered in the hosts file or in DNS\n\n"
	exit 101
fi 


