#!/usr/bin/env bash

# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

POSTINST_HOME=`dirname "$0"`
[ ""$POSTINST_HOME"" = "." ] && POSTINST_HOME=`pwd`

# Varify env file
# tmp dir and backup dir
TMP_DIR=/var/tmp/postinst_`date +'%b-%d-%y'`
[ -d $TMP_DIR ] && rm -rf $TMP_DIR
mkdir $TMP_DIR

PLATFORM=`uname`
case $PLATFORM in
	CYGWIN*)
		cat "$POSTINST_HOME"/postinst_env.sh  |sed -e "s/\\\/\//g" > $TMP_DIR/env_tmp.sh
	        cp -f $TMP_DIR/env_tmp.sh  "$POSTINST_HOME"/postinst_env.sh		
		# stop all related services
		while read line
		do
			./netwrp.sh stop "$line"
        		if [ $? -ne 0 ]; then
                		echo "%POSTINST_BACH-E-STOPSERVICE, failed to stop $line"
                		exit 1
       			fi
		done < "$POSTINST_HOME"/postinst_service.txt
		;;
	*)	
		;;
esac


# set env variables
. "$POSTINST_HOME"/postinst_env.sh

# apply ITDS fix
"$POSTINST_HOME"/postinst_itds.sh  "$ITDS_HOME" "$ITDS_FIX_DIR" "$FIX_FILE" 
rt=$?
if [ $rt -ne 0 ]; then
   echo " %postinst_ids, Apply ITDS fix failed"
   exit 10
fi

# run DB2 license 
"$POSTINST_HOME"/postinst_db2_lic.sh "$DB2_HOME" "$DB2_IMAGE_DIR" "$LICENSE_FILE"
rt=$?
if [ $rt -ne 0 ]; then
   echo " %postinst_db2_lic, run db2 license failed"
   exit 20
fi

# apply DB2 hotfix
"$POSTINST_HOME"/postinst_db2_hotfix.sh "$DB2_HOTFIX_DIR" "$DB2_HOTFIX_PKG"
rt=$?
if [ $rt -ne 0 ]; then
   echo "%postinst_db2_hotfix, apply db2 hotfix failed"
   exit 30
fi

# apply WAS 5.1 CF3
"$POSTINST_HOME"/postinst_was_cf.sh "$WAS_HOME" "$IHS_HOME" "$MQ_HOME" "$WAS_CF3_DIR" "$WAS_CF3_BUILDLEVEL"
rt=$?
if [ $rt -ne 0 ]; then
   echo " %postinst_was_cf3, apply WAS 5.1 CF3 failed"
   exit 40
fi

# apply MQ fix
"$POSTINST_HOME"/postinst_mqfix.sh "$MQ_HOME" "$WAS_MQFIX_DIR"
rt=$?
if [ $rt -ne 0 ]; then
   echo " %postinst_was_mqfix, apply MQ fix failed"
   exit 50
fi

echo "%postinst_bach, successfully applied ITDS fix,DB2 fix, WAS CF3, MQ fixed and registered DB2 license"

#restarting the services

while read line
do
	./netwrp.sh start "$line"
      		if [ $? -ne 0 ]; then
              		echo "%POSTINST_BACH-E-STARTSERVICE, failed to start $line"
              		exit 1
		fi
done < "$POSTINST_HOME"/postinst_service_start.txt



#exit 0