#!/usr/bin/env bash

# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

POSTINST_HOME=`dirname "$0"`
[ "$POSTINST_HOME" = "." ] && POSTINST_HOME=`pwd`

# Validate parameters
NUM_PARA=3
if [ $NUM_PARA -ne $# ]; then
	echo "%POSTINST_ITDS-I-Usage, `basename $0` <ITDS_HOME> <FIX_FILE_LOCATION>" 
        exit $LINENO
fi

#
# Define localy used environment variables
#
PLATFORM=`uname`
case $PLATFORM in
 	CYGWIN*)
		ITDS_HOME=`cygpath -u "$1"`
		FIX_DIR=`cygpath -u "$2"`
		FIX_FILE=$3
		;;
	*)
		ITDS_HOME="$1"
		FIX_DIR="$2"
		FIX_FILE="$3"
		;;
esac

TRG_DIR="$ITDS_HOME/etc"
TMP_DIR=/var/tmp/postinst_`date +'%b-%d-%y'`
mkdir $TMP_DIR/itds_bk

#
# Script starts here
#
# Stop ITDS daemon in case it is running
 
# Check src and target file
for file in "$FIX_DIR/$FIX_FILE" "$TRG_DIR/$FIX_FILE"
do
  if [ ! -f "$file" ]; then
	echo "%POSTINST_ITDS-E-FILE, $file does not exist"
	exit $LINENO 
  fi
done


# Copy over
mv "$TRG_DIR/$FIX_FILE"  "$TMP_DIR/itds_bk"
cp "$FIX_DIR/$FIX_FILE" "$TRG_DIR"
if [ $? -ne 0 ]; then
   echo "%POSTINST_ITDS-E-CP, failed to copy cover fix file from $FIX_DIR/$FIX_FILE  to $TRG_DIR"
   exit $LINENO
fi

getfacl "$TRG_DIR/V3.config.at" | setfacl -f - "$TRG_DIR/$FIX_FILE"

echo "%POSTINST_ITDS-I-DONE,successfully applied ITDS fix"

