#!/usr/bin/env bash

# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

POSTINST_HOME=`dirname "$0"`
[ "$POSTINST_HOME" = "." ] && POSTINST_HOME=`pwd`

# Validate parameters
NUM_PARA=5
if [ $NUM_PARA -ne $# ]; then
        echo "%POSTINST_WAS_CF-I-Usage, `basename $0` <WAS_HOME> <IHS_HOME> <MQ_HOME> <WAS_CF_DIR> <WAS_BUILDLEVEL>"
        exit $LINENO
fi

WAS_HOME="$1"
IHS_HOME="$2"
MQ_HOME="$3"
WAS_CF_DIR="$4"
WAS_BUILDLEVEL="$5"

# Check CF file
WAS_CF_DIR_CYG=`cygpath -u "$WAS_CF_DIR"`
if [ ! -f "$WAS_CF_DIR_CYG/updateSilent.bat" ]; then
	echo "%POSTINST_WAS_CF-E-DIR, $WAS_CF_DIR_CYG/updateSilent.bat does not exist"
	exit $LINENO
fi

cd "$WAS_CF_DIR_CYG"

# Create property file
cat <<EOF > was_cf.properties
  install=true
  installDir=`echo "$WAS_HOME"|sed -e 's/\//\\\\\\\/g'`
  fixpack=true
  fixpackDir=`cygpath -sw "$WAS_CF_DIR/fixpacks" | sed -e 's/\\\/\\\\\\\/g'`
  fixpackID=was510_cf3_win
  ihsInstallDir=`echo "$IHS_HOME"|sed -e 's/\//\\\\\\\/g'`
  mqInstallDir=`echo "$MQ_HOME"|sed -e 's/\//\\\\\\\/g'`
EOF
  #skipIHS=true
  #skipMQ=true
cat was_cf.properties

# Create cmd file
cat <<EOF > my.cmd 
call "`echo $WAS_HOME|sed -e 's/\//\\\/g'`\bin\setupCmdLine.bat"
echo %JAVA_HOME%
updateSilent.bat was_cf.properties
EOF

chmod 754 my.cmd
cmd /c "my.cmd" 

#if [ $? -ne 0 ]; then
#	echo "%POSTINST_WAS_CF-E-RESULT, failed to apply cumulated fix"
#	exit $LINENO
#fi

# Check buildlevel afterward

result=`cmd /c "$WAS_HOME/bin/versionInfo.bat" 2>&1 |grep $WAS_BUILDLEVEL| wc -l`
if [ $result -ne 1 ]; then
	echo "%POSTINST_WAS_CF-E-RESULT, failed to apply cumulated fix"
        exit $LINENO
fi

echo "%POSTINST_WAS_CF-I-DONE, applied cumulated fix successfully"
