#!/usr/bin/env bash

# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

#_________________________________________________________
#                                                         #
# Load the global response file                           #
#_________________________________________________________#
#

if [ -e ./tpm_install.req ]
then
	. ./tpm_install.req
else
	printf "TPM response file not found\n\n"
	exit 1
fi

if [ -z "$CYG_ROOT" ]
then
	CYG_BIN=`cygpath -w /bin`
	CYG_ROOT=${CYG_BIN%\\*}
fi

TPM_HOST_NAME=$(hostname)

#_________________________________________________________
#                                                         #
# Find the Administrator/Admins group                     #
#_________________________________________________________#
#

admin_user=$(id -un)
if [ -z "$admin_user" ]; then
	printf "\n\nCannot identify the Administrator user"
	exit 101
fi

admin_groups=$(id)
admin_tmp=${admin_groups##*544(}
admin_group=${admin_tmp%%)*}
if [ -z "$admin_group" ]; then
	printf "\n\nCannot identify the Administrator group"
	exit 101
fi

#_________________________________________________________
#                                                         #
# Check the environment                                   #
#_________________________________________________________#
#

if [ -e ./media_check.sh ]
then
	. ./media_check.sh
else
	printf "Media check script file not found\n\n"
	exit 1
fi

#_________________________________________________________
#                                                         #
# Generate the PICS environment                           #
#_________________________________________________________#
#

cat << EOFEOF > ./pics_env.sh
#!/usr/bin/env bash

BASE_DIR="${BASE_DIR}"
PICS_SRC="${BASE_DIR}\\${PICS_SRC}"
DB2_SRC="${BASE_DIR}\\${DB2_SRC}"
DB2_FIXPACK_SRC="${BASE_DIR}\\${DB2_FIXPACK_SRC}"
DB2_HOME="${DB2_HOME}"
DB_ADMIN_USER="$DB2_ADMIN_USER"
DB_ADMIN_PWD="$DB2_ADMIN_PWD"
LDAP_SRC="${BASE_DIR}\\${ITDS_SRC}"
ITDS_HOME="${ITDS_HOME}"
WAS_SRC="${BASE_DIR}\\${WAS_SRC}"
WAS_HOME="${WAS_HOME}"
EOFEOF

#_________________________________________________________
#                                                         #
# Generate the postinstall environment                    #
#_________________________________________________________#
#

cat << EOFEOF > ./postinst_env.sh
# Location of fixes
FIX_DIR="${BASE_DIR}\\${FIX_DIR}"

# For postinst_ids.sh
ITDS_HOME="${ITDS_HOME}"
ITDS_FIX_DIR=\$FIX_DIR\ITDS
FIX_FILE=V3.ibm.at

# For postinst_db2_lic.sh and postinst_db2_hotfix.sh
DB2_HOME="$DB2_HOME"
DB2_IMAGE_DIR="${BASE_DIR}\\${DB2_SRC}"
LICENSE_FILE=db2/license/db2wsue.lic
DB2_HOTFIX_DIR="\$FIX_DIR\DB2\Windows"
DB2_HOTFIX_PKG=hotfixpkg_10831.exe

# For postint_was_cf3.sh,  postinst_was_mqfix.sh
WAS_HOME="$WAS_HOME"
WAS_CF3_DIR=\$FIX_DIR\WAS\was510_cf3_win
WAS_CF3_BUILDLEVEL="cf30412.02"
IHS_HOME="${WAS_HOME}/HTTPServer"
MQ_HOME="${WAS_HOME}/MQ"
WAS_MQFIX_DIR=\$FIX_DIR\WAS\IC38409
EOFEOF

#_________________________________________________________
#                                                         #
# Generate the registry key for runonce after the reboot  #
#_________________________________________________________#
#

LOCAL_DIR_CYG=$(cygpath "${BASE_DIR}"/"${PICS_SRC}" | sed -e 's/ /\\\\ /g')
INSTALL_SCR="${LOCAL_DIR_CYG}/tpm_install/tpm_install.sh"

RUNONCE_BASH="`echo $CYG_ROOT | sed -e 's/\\\/\\\\\\\/g'`\\\bin\\\bash.exe"

cat << EOFEOF > ./tpm_finish.reg
Windows Registry Editor Version 5.00

[HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows\CurrentVersion\RunOnce]
"TPM Installation"="cmd /C start ${RUNONCE_BASH} -l -c '${INSTALL_SCR};bash'"

EOFEOF


#_________________________________________________________
#                                                         #
# Generate the LDAP config environment                    #
#_________________________________________________________#
#

cat << EOFEOF > ./ldap_env.sh
#!/usr/bin/env bash

CYG_ROOT="$CYG_ROOT"
ITDS_HOME="$ITDS_HOME"
LDAP_DB_HOME="$ITDS_DB_HOME"
LDAP_ADMIN_DN="$ITDS_ADMIN_DN"
LDAP_ADMIN_PWD="$ITDS_ADMIN_PWD"
LDAP_DB_ADMIN_USER="$ITDS_DB_ADMIN_USER"
LDAP_DB_ADMIN_PWD="$ITDS_DB_ADMIN_PWD"
LDAP_DB_NAME="$ITDS_DB_NAME"
admin_user="$admin_user"
admin_group="$admin_group"
EOFEOF

#_________________________________________________________
#                                                         #
# Generate the TPM environment                            #
#_________________________________________________________#
#

cat << EOFEOF > ./tpm_env.sh
CYG_ROOT="$CYG_ROOT"
TPM_SRC="${BASE_DIR}\\${TPM_SRC}"
TPM_HOME="$TPM_HOME"
TIO_ADMIN_PWD="$TIO_ADMIN_PWD"
HOSTNAME="$HOSTNAME"
DB2_HOME="$DB2_HOME"
DB_ADMIN_USER="$DB2_ADMIN_USER"
DB_ADMIN_PWD="$DB2_ADMIN_PWD"
TIO_DB_NAME="$TIO_DB_NAME"
BASE_DN="$BASE_DN"
ITDS_ADMIN_DN="$ITDS_ADMIN_DN"
ITDS_ADMIN_PWD="$ITDS_ADMIN_PWD"
WAS_HOME="$WAS_HOME"
MQ_HOME="${WAS_HOME}\MQ"
ITDS_HOME="$ITDS_HOME"
admin_user="$admin_user"
admin_group="$admin_group"
export admin_user admin_group

EOFEOF

#_________________________________________________________
#                                                         #
# Generate the TPM FixPack 1 environment                  #
#_________________________________________________________#
#

cat << EOFEOF > ./tpm_fixpack1_env.sh
FP1_ZIP="${BASE_DIR}\\${TPM_FIXPACK1}\2.1.0.1-TIV-TPM-FP01-WIN.zip"
TPM_HOME="$TPM_HOME"
WAS_HOME="$WAS_HOME"
DB2_HOME="${DB2_HOME}"
TC_ROOT="$CYG_ROOT"
TIO_ADMIN_PWD="$TIO_ADMIN_PWD"
admin_user="$admin_user"
admin_group="$admin_group"
export admin_user admin_group

EOFEOF

#_________________________________________________________
#                                                         #
# Generate the DCM reinit environment                     #
#_________________________________________________________#
#

cat << EOFEOF > ./reinit_env.sh
TPM_HOME="$TPM_HOME"
DB2_HOME="${DB2_HOME}"
WAS_HOME="$WAS_HOME"
admin_user="$admin_user"
admin_group="$admin_group"
EOFEOF

#_________________________________________________________
#                                                         #
# Generate the DCM xml import file                        #
#_________________________________________________________#
#

PATCH_REPOSITORY=${TPM_HOME%%:*}

cat << EOFEOF > ./tcm-dcm.xml
<!DOCTYPE datacenter PUBLIC "-//Think Dynamics//DTD XML Import//EN"
    "http://www.thinkdynamics.com/dtd/xmlimport.dtd">
<datacenter>
	<switch-fabric name="Default Fabric"/>
	<discovery name="Windows All - English" description="Discovers new patches available on a Microsoft SUS server and automatically updates the DCM" locale="en_US">
		<property name="platform" value="All"/>
		<property name="local.path" value="$PATCH_REPOSITORY:\\\SUS"/>
	</discovery>
	<discovery name="Windows All - French" description="Discovers new patches available on a Microsoft SUS server and automatically updates the DCM" locale="fr_FR">
		<property name="platform" value="All"/>
		<property name="local.path" value="$PATCH_REPOSITORY:\\\SUS"/>
	</discovery>	
	<discovery name="Windows All - Italian" description="Discovers new patches available on a Microsoft SUS server and automatically updates the DCM" locale="it_IT">
		<property name="platform" value="All"/>
		<property name="local.path" value="$PATCH_REPOSITORY:\\\SUS"/>
	</discovery>
	<discovery name="Windows All - German" description="Discovers new patches available on a Microsoft SUS server and automatically updates the DCM" locale="de_DE">
		<property name="platform" value="All"/>
		<property name="local.path" value="$PATCH_REPOSITORY:\\\SUS"/>
	</discovery>
	<discovery name="Windows All - Japanese" description="Discovers new patches available on a Microsoft SUS server and automatically updates the DCM" locale="ja_JP">
		<property name="platform" value="All"/>
		<property name="local.path" value="$PATCH_REPOSITORY:\\\SUS"/>
	</discovery>
	<discovery name="Windows All - Chinese Simplified" description="Discovers new patches available on a Microsoft SUS server and automatically updates the DCM" locale="zh_CN">
		<property name="platform" value="All"/>
		<property name="local.path" value="$PATCH_REPOSITORY:\\\SUS"/>
	</discovery>
	<discovery name="Windows All - Chinese Traditional" description="Discovers new patches available on a Microsoft SUS server and automatically updates the DCM" locale="zh_TW">
		<property name="platform" value="All"/>
		<property name="local.path" value="$PATCH_REPOSITORY:\\\SUS"/>
	</discovery>	
	<discovery name="Windows All - Korean" description="Discovers new patches available on a Microsoft SUS server and automatically updates the DCM" locale="ko_KR">
		<property name="platform" value="All"/>
		<property name="local.path" value="$PATCH_REPOSITORY:\\\SUS"/>
	</discovery>
	<discovery name="Windows All - Portuguese (Brazilian)" description="Discovers new patches available on a Microsoft SUS server and automatically updates the DCM" locale="pt_BR">
		<property name="platform" value="All"/>
		<property name="local.path" value="$PATCH_REPOSITORY:\\\SUS"/>
	</discovery>
	<subnetwork ipaddress="$SUS_IP_ADDRESS" netmask="255.255.255.255">
		<vlan vlan-number="1" fabric="Default Fabric"/>
	</subnetwork>
	<spare-pool name="MS-SUS" os-type="Windows" vlan="1" fabric="Default Fabric" locale="en_US">
		<server name="$SUS_SERVER_NAME" locale="en_US">
			<network-interface name="MGMT" ipaddress="$SUS_IP_ADDRESS" netmask="255.255.255.255" managed="false" locale="en_US"/>
			<sap name="HTTP get" port="80" host="true" protocol-type="other" other-type-description="HTTP" locale="en_US">
				<credentials search-key="tcm_tpm" is-default="true">
					<password-credentials username="$SUS_SERVER_USER" password="$SUS_SERVER_PASSWORD"/>
				</credentials>
			</sap>
			<discovery-association discovery="Windows All - English"/>
		</server>
		<server name="$TPM_HOST_NAME" locale="en_US">
			<sap name="local" port="80" host="true" protocol-type="other" other-type-description="HTTP" locale="en_US">
				<default-sap operation-type="execute-command"/>
			</sap>
		</server>
		<server name="go.microsoft.com" locale="en_US">
			<property component="KANAHA" name="mscab_url" value="/fwlink/?LinkID=18922"/>
		</server>
	</spare-pool>
	<kanaha-config>
		<dcm-object id="0">
			<property component="KANAHA" name="SUS_Server" value="$SUS_SERVER_NAME"/>
			<property component="KANAHA" name="MSSecure_Server" value="go.microsoft.com"/>
		</dcm-object>
	</kanaha-config>
</datacenter>
EOFEOF