#!/usr/bin/env bash

# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

if [ -e ./tpm_env.sh ]
then
	. ./tpm_env.sh
else
	printf "tpm_env.sh file not found\n\n"
	exit 1
fi

INSTALL_HOME=$(pwd)
export PATH=$PATH:$(cygpath "${ITDS_HOME}"/jre/bin)
cd "`echo $TPM_SRC | sed -e 's/\\\/\//g'`"/tools

ENC_TIO_ADMIN=`./encrypt.sh $TIO_ADMIN_PWD`
ENC_TIO_ADMIN_PWD=${ENC_TIO_ADMIN##* }

ENC_DB_ADMIN=`./encrypt.sh $DB_ADMIN_PWD`
ENC_DB_ADMIN_PWD=${ENC_DB_ADMIN##* }

ENC_ITDS_ADMIN=`./encrypt.sh $ITDS_ADMIN_PWD`
ENC_ITDS_ADMIN_PWD=${ENC_ITDS_ADMIN##* }

DNS_SUFFIX=${HOSTNAME#*.}

cd "$INSTALL_HOME"

cat << EOFEOF > tpm_bach.req
-W cygwinbean.cygwin_dir="$CYG_ROOT"
-W WzdIP_TCHome.TCHome="$TPM_HOME"
-W WzdIP_UsrGrpName_Disp.Password="$ENC_TIO_ADMIN_PWD"
-W WzdIP_UsrGrpName_Disp.VerifyPassword="$ENC_TIO_ADMIN_PWD"
-W WzdIP_LangPack.ChkInstallLangPack="1"
-W WzdIP_DBType.DBType="db2"
-W WzdIP_DBType.ConfigChoice=""
-W WzdIP_DB2.HostName="$HOSTNAME"
-W WzdIP_DB2.Port="50000"
-W WzdIP_DB2.DBName="$TIO_DB_NAME"
-W WzdIP_DB2.AdminAccessName="$DB_ADMIN_USER"
-W WzdIP_DB2.AdminPassword="$ENC_DB_ADMIN_PWD"
-W WzdIP_DB2.DBUserName="$DB_ADMIN_USER"
-W WzdIP_DB2.DBUserPwd="$ENC_DB_ADMIN_PWD"
-W WzdIP_DB2.ClientDir="$DB2_HOME"
-W WzdIP_LDAPType.LDAPType="ibmds"
-W WzdIP_LDAPType.ConfigChoice=""
-W WzdIP_IBMDS.BaseDN="$BASE_DN"
-W WzdIP_IBMDS.AdminName="$ITDS_ADMIN_DN"
-W WzdIP_IBMDS.AdminPassword="$ENC_ITDS_ADMIN_PWD"
-W WzdIP_IBMDS.HostName="$HOSTNAME"
-W WzdIP_IBMDS.Port="389"
-W WzdIP_IBMDS.ClientDir="$ITDS_HOME"
-W WzdIP_IBMDS.SSLEnabled=""
-W WzdIP_MSADInput.BaseDN=""
-W WzdIP_MSADInput.AdminName=""
-W WzdIP_MSADInput.AdminPassword=""
-W WzdIP_MSADInput.HostName=""
-W WzdIP_MSADInput.Port=""
-W WzdIP_MSADInput.SSLPort=""
-W WzdIP_MSADInput.SSLEnabled=""
-W WzdIP_WAS.DNSSuffixName="$DNS_SUFFIX"
-W WzdIP_WAS.InstallDir="$WAS_HOME"
-W WzdIP_WAS.MQInstallDir="$MQ_HOME"
-W WzdIP_NetView.ChkNetViewInstall=""
-W WzdIP_NetViewWin.Password=""
-W WzdIP_NetViewWin.VerifyPassword=""
-P ProdFeat_Reinit.active="False"
EOFEOF

cp tpm_bach.req "`echo $TPM_SRC | sed -e 's/\\\/\//g'`"
if [ $? -ne 0 ]
then
	printf "Error trying to copy tpm response file"
	exit 101
fi

cd "`echo $TPM_SRC | sed -e 's/\\\/\//g'`"

printf "Installing TPM For Patch Automation....\n\n"


TPM_SRC_CYG=`cygpath -u "$TPM_SRC"`

"$INSTALL_HOME"/call_tpm_installer.sh "$TPM_SRC_CYG" "$TPM_SRC_CYG/tpm_bach.req"

if [ $? -ne 0 ]; then
	echo "failed to install tpm"
	exit 2
fi

chown -R tioadmin:$admin_group $(cygpath "$TPM_HOME")
if [ $? -ne 0 ]; then
	echo "Unable to change owner for $TPM_HOME"
	exit 2
fi

chmod -R ug+rwx $(cygpath "$TPM_HOME")
if [ $? -ne 0 ]; then
	echo "Unable to change access rights for $TPM_HOME"
	exit 2
fi

cd "$INSTALL_HOME"
regedit -s ./tpm_name.reg
if [ $? -ne 0 ]; then
	echo "Unable to change TPM_NAME"
	exit 2
fi

echo "successfully installed TPM For Patch Automation"
