#!/usr/bin/env bash

# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

if [ -e ./tpm_fixpack1_env.sh ]
then
	. ./tpm_fixpack1_env.sh
else
	printf "%%TPM_FIXPACK1 : tpm_fixpack1_env.sh file not found\n\n"
	exit 1
fi

./netwrp.sh start "IBM Tivoli Directory Server V5.2"
if [ $? -ne 0 ]; then
	printf "%%TPM_FIXPACK1 : Failed to start IBM Tivoli Directory Server V5.2\n\n"
	exit 101
fi

TEMP_DIR=/var/tmp/postinst_`date +'%b-%d-%y'`
[ -d $TEMP_DIR ] && rm -rf $TEMP_DIR
mkdir $TEMP_DIR

FP1_ZIP_CYG=`cygpath -u "$FP1_ZIP"`

unzip -qq -d "$TEMP_DIR" "$FP1_ZIP_CYG"
if [ $? -ne 0 ]
then
	printf "%%TPM_FIXPACK1 : Error extracting the content of DB2 HotFix\n\n"
	exit 101
fi

TIO_HOME=$TPM_HOME; export TIO_HOME
JAVA_HOME="$WAS_HOME"\\java;export JAVA_HOME
export WAS_HOME TC_ROOT DB2_HOME
FP1_DIR_WIN=`cygpath -sw "$TEMP_DIR"`
FP1_JAR_WIN=`cygpath -sw "$TEMP_DIR/installer"`
WAS_HOME_CYG=`cygpath -u "$WAS_HOME"`

SYS_DIR="`cygpath -S`"
TIV_DIR="${SYS_DIR%%/WINDOWS/system32}/Program Files/ibm/tivoli/common/COP/logs"
#TIO_LOGS="`cygpath -w "$TIV_DIR"`"

cp installer.jar "$FP1_JAR_WIN"
if [ $? -ne 0 ]
then
	printf "%%TPM_FIXPACK1 : Error trying to patch installer.jar file"
	exit 101
fi

cp updateSilent.bat "$FP1_JAR_WIN"
if [ $? -ne 0 ]
then
	printf "%%TPM_FIXPACK1 : Error trying to copy updateSilent.bat file"
	exit 101
fi

cp update_xmi.sh "$FP1_JAR_WIN"
if [ $? -ne 0 ]
then
	printf "%%TPM_FIXPACK1 : Error trying to copy update_xmi.sh file"
	exit 101
fi

cp ownership.sh "$FP1_JAR_WIN\\utils"
if [ $? -ne 0 ]
then
	printf "%%TPM_FIXPACK1 : Error trying to copy ownership.sh file"
	exit 101
fi

cp postinstall.bat "$FP1_JAR_WIN\\utils"
if [ $? -ne 0 ]
then
	printf "%%TPM_FIXPACK1 : Error trying to copy postinstall.bat file"
	exit 101
fi

cd "$FP1_JAR_WIN"

cat << EOFEOF > fp1.cmd
@echo off
call $WAS_HOME\bin\setupCmdLine.bat
@echo on
call updateSilent.bat fixpack install $TPM_HOME tpm20_fp1_win $FP1_JAR_WIN
EOFEOF

cmd /c fp1.cmd
if [ $? -ne 0 ]
then
	printf "%%TPM_FIXPACK1 : Error installing the TPM FixPack 1"
	exit 101
fi

./update_xmi.sh
if [ $? -ne 0 ]
then
	printf "%%TPM_FIXPACK1 : Error updating the xmi"
	exit 101
fi

chmod -R 777 "$TEMP_DIR"

cd utils
if [ $? -ne 0 ]
then
	printf "%%TPM_FIXPACK1 : No such directory: `pwd`/utils"
	exit 101
fi

#cat << EOFEOF > postinst.cmd
#set TC_ROOT=$TC_ROOT
#set TIO_HOME=$TPM_HOME
#set WAS_HOME=$WAS_HOME
#call postinstall.bat wasadmin wasadmin
#EOFEOF

#cmd /c postinst.cmd
cmd /c postinstall.bat wasadmin wasadmin

if [ $? -ne 0 ]
then
	printf "%%TPM_FIXPACK1 : Error running the FixPack1 postinstall process"
	exit 101
fi


"$WAS_HOME_CYG"/bin/WASService.exe -add IBM_TPM -serverName server1 -userid tioadmin -password \
		"$TIO_ADMIN_PWD" -wasHome "$WAS_HOME" -logFile "$WAS_HOME"\logs\server1_Service.log \
		-logRoot "$WAS_HOME"\logs\server1 -restart true -stopArgs " -user wasadmin -password wasadmin"
if [ $? -ne 0 ]
then
	printf "%%TPM_FIXPACK1 : Error applying the upd_service fix"
	exit 101
fi

cd

rm -r "$TEMP_DIR"
if [ $? -ne 0 ]
then
	printf "%%TPM_FIXPACK1 : Error cleaning up the temporary directory"
	exit 101
fi

chown -R tioadmin:$admin_group $(cygpath "$TPM_HOME")
if [ $? -ne 0 ]; then
	echo "Unable to change owner for $TPM_HOME"
	exit 2
fi

chmod -R ug+rwx $(cygpath "$TPM_HOME")
if [ $? -ne 0 ]; then
	echo "Unable to change access rights for $TPM_HOME"
	exit 2
fi