#!/usr/bin/env bash
# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------
# Ver. 2.1.10
#
INSTALL_HOME=$(dirname "$0")

cd "$INSTALL_HOME"
#_________________________________________________________
#                                                         #
# Load the execution file                                 #
#_________________________________________________________#
#

if [ -e ./exec-flow.txt ]
then
	exec_sequence=./exec-flow.txt
else
	printf "Task file not found\n\n"
	exit 1
fi

#_______________________________________________________#
#                                                       #
# Remove old tpm_install.log files                      #
#                                                       #
#_______________________________________________________#
#

if [ -f ./tpm_install_* ]; then
   rm ./tpm_install_*
fi


#________________________________________________________#
#                                                        #
# Move tpm_install.log to tpm_install_old.log            #
#________________________________________________________# 
#

INSTALL_DATE=`date +%m%d%y_%H%M%S`
LOG_FILE=./tpm_install.log
LOG_FILE_OLD=./tpm_install_${INSTALL_DATE}.log

if [ -f "$LOG_FILE" ]
   then
   mv -f "$LOG_FILE" "$LOG_FILE_OLD"
fi


#_________________________________________________________
#                                                         #
# Identifying the current OS type                         #
#_________________________________________________________#
#

case `uname` in
	Linux)
		awk_cmd=gawk
		os_type=linux
		;;
	CYGWIN_NT-5.[012])
		awk_cmd=gawk
		os_type=windows
		;;
	SunOS)
		awk_cmd=nawk
		os_type=solaris
		;;
	*)
		echo "Unknown operating system"
		exit 1
		;;
esac

#_________________________________________________________
#                                                         #
# Test for the install options                            #
#_________________________________________________________#
#

. ./tpm_rerun.sh

#_________________________________________________________
#                                                         #
# Iterate through the tasks list                          #
#_________________________________________________________#
#

printf "\n\n"
cp $exec_sequence ./exec-flow.iteration
printf "_______________________________________________________________________________\n\n\n"


IFS=";"
cat ./exec-flow.iteration | while read task_name command_name status
do
	case $status in
		ready)
			printf "$task_name completed successfully. Please review the tpm_install.log.\n\n"
			printf "_______________________________________________________________________________\n\n\n"
			;;
		failed)
			printf "The previous execution of $task_name failed,\nplease fix the problem. update exec-flow.txt(i.e. replace failed with not_ready) and use the \"continue\" option\n\n"
			printf "_______________________________________________________________________________\n\n\n"
			exit 101
			;;
		not_ready)
			printf "Running $task_name .... please wait....\n\n"

			status=ready
			cat $exec_sequence | $awk_cmd \
						'BEGIN { FS = ";" }; \
						$0 ~ task_name {print $1";"$2";"status}; \
						$0 !~ task_name {print $0}' task_name=^"$task_name" status=$status \
					> ./exec-flow-tmp.$$
			/bin/mv ./exec-flow-tmp.$$ $exec_sequence
			
			./progress_bar.sh &
			progress_pid=$!

			printf "\n ____________________________________________________________________________\n" >> tpm_install.log
			printf "|\n" >> tpm_install.log
			printf "|           Running $task_name\n" >> tpm_install.log
			printf "|           $(date)\n" >> tpm_install.log
			printf "|____________________________________________________________________________\n\n" >> tpm_install.log			
			
			$command_name 2>&1 >> tpm_install.log
			if [ $? -ne 0 ]; then
				status=failed
				cat $exec_sequence | $awk_cmd \
							'BEGIN { FS = ";" }; \
							$0 ~ task_name {print $1";"$2";"status}; \
							$0 !~ task_name {print $0}' task_name=^"$task_name" status=$status \
						> ./exec-flow-tmp.$$
				/bin/mv ./exec-flow-tmp.$$ $exec_sequence
				kill $progress_pid 2>&1 > /dev/null
				printf "\n\n$task_name failed, installation will be aborted.\n"
				printf "See the log file "$INSTALL_HOME"/tpm_install.log for details. Please update exec-flow.txt before rerunning the installation (i.e. replace failed with not_ready).\n" 
				printf "_______________________________________________________________________________\n\n\n"
				exit 1
			fi
			
			kill $progress_pid 2>&1 > /dev/null
			printf "\n\n$task_name completed successfully. Please review the tpm_install.log.\n\n"
			printf "_______________________________________________________________________________\n\n\n"
			;;
	esac
			
done

exit 0
