#!/usr/bin/env bash

# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

if [ -e ./reinit_env.sh ]
then
	. ./reinit_env.sh
else
	printf "%%TPM_REINIT : reinit_env.sh file not found\n\n"
	exit 1
fi

cp tcm-dcm.xml "$TPM_HOME\\xml"
if [ $? -ne 0 ]
then
	printf "%%TPM_REINIT : Error trying to copy tcm-dcm.xml\n\n"
	exit 101
fi

TPM_HOME_CYG=`cygpath -sw $TPM_HOME`

while read filename
do
	if [ -f "$TPM_HOME_CYG/drivers/$filename" ]
	then
		rm -f "$TPM_HOME_CYG/drivers/$filename"
	fi
done < ./tcdriver-list.txt

cp tcm-ms-patches.tcdriver "$TPM_HOME_CYG/drivers/"
if [ $? -ne 0 ]
then
	printf "%%TPM_REINIT : Error deploying tcm-ms-patches.tcdriver\n\n"
	exit 101
fi

cp header.expect "$TPM_HOME_CYG/tools/scriptlet"
if [ $? -ne 0 ]
then
	printf "%%TPM_REINIT : Error patching header.expect\n\n"
	exit 101
fi

./secedit.sh

#cp TEDWScheduler.ini "$TPM_HOME"/config

cp logo-patch.jar "$TPM_HOME"
cd "$TPM_HOME"
$WAS_HOME/java/bin/jar xf logo-patch.jar 
if [ $? -ne 0 ]
then
	printf "%%TPM_REINIT : Error patching Forms.properties files\n\n"
	exit 101
fi
rm -f logo-patch.jar

if [ -d $TPM_HOME/license ]; then
        rm -r $(cygpath $TPM_HOME/license)/*
fi

cd "$TPM_HOME\\tools"

./reinit.cmd ..\\xml\\tcm-dcm.xml
if [ $? -ne 0 ]
then
	printf "%%TPM_REINIT : Error initializing the DCM database\n\n"
	exit 101
fi

chown -R tioadmin:$admin_group $(cygpath $TPM_HOME)
if [ $? -ne 0 ]
then
	printf "%%TPM_REINIT : Error changing the group owner for TPM libraries\n\n"
	exit 101
fi

chown -R tioadmin $(cygpath $WAS_HOME)
if [ $? -ne 0 ]
then
	printf "%%TPM_REINIT : Error changing WebSphere owner to tioadmin\n\n"
	exit 101
fi

printf "\n\n"
printf "%%TPM_REINIT : DCM database initialization successfull\n\n"