#!/usr/bin/env bash
#
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or 
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#
# Usage: ./update_xmi.sh
###########################################################################

echo "###################################################"
echo "Get the Environment variables from tioadmin user:"

case `uname` in
  Linux)
     CMD=`grep TCprofile ~tioadmin/.*profile | tail -1 | cut -d' ' -f2`
     . $CMD
     ;;
  AIX)
     CMD=`grep TCprofile ~tioadmin/.profile | tail -1 | cut -d' ' -f2`
     . $CMD
     ;;
  SunOS)
     CMD=`grep TCprofile ~tioadmin/.profile | tail -1 | cut -d' ' -f2`
     . $CMD
     ;;
  CYGWIN*)
     ;;
  *)
     echo "Unable to determine Operating System"
     exit 0
esac

if [ -z "$TIO_HOME" ]; then
   echo "Error: $TIO_HOME is not defined" 
   exit 2
else
   echo "TIO_HOME=$TIO_HOME" 
fi

if [ -z "$WAS_HOME" ]; then
   echo "Error: WAS_HOME is not defined"
   exit 2
else
   echo "WAS_HOME=$WAS_HOME" 
fi

if [ -z "$JAVA_HOME" ]; then
   echo "Error: JAVA_HOME is not defined"
   exit 2
else
   echo "JAVA_HOME=$JAVA_HOME" 
fi

CONFDIR=$TIO_HOME/config
LIBDIR=$TIO_HOME/lib

# Get required suffix from user-factory.xml file
USERFACTORYXML=$CONFDIR/user-factory.xml

TC__LDAPDOMAIN=`grep '<root>' $USERFACTORYXML | sed -e 's^\(.*\)<root>\(.*\)</root>\(.*\)^\2^'`
echo "###################################################"

if [ $? -eq 0 ]; then
	echo "Found entry of $TC__LDAPDOMAIN in $USERFACTORYXML"
else
	echo "Missing entry of $TC__LDAPDOMAIN in $USERFACTORYXML"
	exit 2
fi

# Backup the tcje.ear file
echo "###################################################"
echo "Backing up $TIO_HOME/apps/tcje.ear"

case `uname` in
  Linux)
     cp "$TIO_HOME"/apps/tcje.ear "$TIO_HOME"/apps/tcje.ear_$$
     CLASSPATH=$CLASSPATH:$LIBDIR/plumbing.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/datacentermodel.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/datamigration.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/log4j.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/jdom.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/commons-resources.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/commons-logging.jar
     CLASSPATH=$CLASSPATH:$ORACLE_HOME/jdbc/lib/classes12.zip
     CLASSPATH=$CLASSPATH:$DB2_HOME/java/db2java.zip
     ;;
  AIX)
     cp "$TIO_HOME"/apps/tcje.ear "$TIO_HOME"/apps/tcje.ear_$$
     CLASSPATH=$CLASSPATH:$LIBDIR/plumbing.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/datacentermodel.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/datamigration.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/log4j.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/jdom.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/commons-resources.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/commons-logging.jar
     CLASSPATH=$CLASSPATH:$ORACLE_HOME/jdbc/lib/classes12.zip
     CLASSPATH=$CLASSPATH:$DB2_HOME/java/db2java.zip
     ;;
  SunOS)
     cp "$TIO_HOME"/apps/tcje.ear "$TIO_HOME"/apps/tcje.ear_$$
     CLASSPATH=$CLASSPATH:$LIBDIR/plumbing.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/datacentermodel.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/datamigration.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/log4j.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/jdom.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/commons-resources.jar
     CLASSPATH=$CLASSPATH:$LIBDIR/commons-logging.jar
     CLASSPATH=$CLASSPATH:$ORACLE_HOME/jdbc/lib/classes12.zip
     CLASSPATH=$CLASSPATH:$DB2_HOME/java/db2java.zip
     ;;
  CYGWIN*)
     chmod u+r "$TIO_HOME/apps/tcje.ear"
     chmod u+r "$TIO_HOME/lib/plumbing.jar"
     chmod u+r "$TIO_HOME/lib/datacentermodel.jar"
     cp "$TIO_HOME"/apps/tcje.ear "$TIO_HOME"/apps/tcje.ear_$$
     CLASSPATH=""

     for LIB in plumbing datacentermodel datamigration log4j jdom commons-resources commons-logging
     do
        TEMPDIR=`cygpath -ws "$LIBDIR"/${LIB}.jar`
        CLASSPATH=$CLASSPATH\;$TEMPDIR
     done

     if [ ! -z "$ORACLE_HOME" ]; then
        TEMPDIR=`cygpath -ws "$ORACLE_HOME"/jdbc/lib/classes12.zip`
        CLASSPATH=$CLASSPATH\;$TEMPDIR
     fi

     TEMPDIR=`cygpath -ws "$DB2_HOME"/java/db2java.zip`
     CLASSPATH=$CLASSPATH\;$TEMPDIR
     ;;
  *)
     echo "Unable to determine Operating System"
     exit 0
esac

echo "###################################################"
echo "CLASSPATH=$CLASSPATH"
echo "###################################################"
echo "Synchronizing $TIO_HOME/apps/tcje.ear with entry from $USERFACTORYXML"
echo "###################################################"

"$JAVA_HOME"/bin/java -classpath "$CLASSPATH" \
 -Dkanaha.logs="$TIO_LOGS" \
 -Dlog4j.configuration=file:///"$CONFDIR"/log4j.prop \
 -Dkanaha.config=file:///"$CONFDIR" \
 com.thinkdynamics.tools.BaseDNUpdate "$TIO_HOME"/apps $TC__LDAPDOMAIN

echo "The tcje.ear has been updated" 
exit $?
